#!/bin/sh -e

# Move to configuration directory
cd /mnt/fsuser-1/spf/etc

# Create configuration and version files
ln -fs /mnt/fsuser-1/spf/etc/global_conf.json /tmp/packet_forwarder.conf
echo spf 3.1.0-klk16 +hal_libloragw_4.1.3-klk8 > /tmp/packet_forwarder_version.txt

# Restart modem
[ -z "$(which modem_off.sh)" ] || modem_off.sh
[ -z "$(which modem_on.sh)" ] || modem_on.sh | logger -p local1.notice -t spf

# Open firewall ports
iptables_accept() {
	local RULE="OUTPUT -t filter -p udp --dport ${1} -j ACCEPT"
	iptables -C ${RULE} 2> /dev/null || iptables -I ${RULE}
	local RULE="INPUT -t filter -p udp --sport ${1} -j ACCEPT"
	iptables -C ${RULE} 2> /dev/null || iptables -I ${RULE}
}

iptables_accept "$(/mnt/fsuser-1/spf/bin/configure_spf "gateway_conf.serv_port_up")"
iptables_accept "$(/mnt/fsuser-1/spf/bin/configure_spf "gateway_conf.serv_port_down")"

# Wait until server is available
trap "exit" INT QUIT TERM
while true
do
	if ! server="$(/mnt/fsuser-1/spf/bin/configure_spf "gateway_conf.server_address")"
	then
		echo "Failed to get server address" | \
			logger -p local1.notice -t spf
		exit 1
	elif ! nslookup ${server} > /dev/null 2>&1
	then
		echo "Waiting until server '${server}' is available" | \
			logger -p local1.notice -t spf
		sleep 30
	else
		break
	fi
done

# Lock on pid file
exec 8> /var/run/packet_forwarder.pid
flock -n -x 8
trap "rm -f /var/run/packet_forwarder.pid" EXIT

# Start packet forwarder
/mnt/fsuser-1/spf/bin/spf 2>&1 | logger -p local1.notice -t spf &
trap "killall -q spf" INT QUIT TERM

# Update pid and wait for it
pidof spf >&8
wait
